# 关于common包

common和base是比较容易混淆的两个名词

- base指的是基础的东西，比如模板、基类等等
- common的范围比较广，一般指常识、常见的、公共的组件（可以理解base是common的一部分）

base包包含的内容：
- 模板
- 基础的技术组件，比如样式/脚本/前端组件


# 案例

## 用到base的例子

- 基类的名称，比如BaseTemplate


## 用到common的例子

- apache的commons组件 